@@ -17,12 +17,12 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
 #include <Python.h>
-#include <glib/gspawn.h>
+#include <glib.h>
 
 #include "pyglib.h"
 #include "pyglib-private.h"
