@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -29,6 +29,8 @@
 #include "pyginterface.h"
 #include "pygparamspec.h"
 
+#include "pygi-external.h"
+
 
 static void pygobject_dealloc(PyGObject *self);
 static int  pygobject_traverse(PyGObject *self, visitproc visit, void *arg);
@@ -422,8 +424,7 @@ static PySequenceMethods _PyGProps_as_sequence = {
     0
 };
 
-struct empty {} _empty;
-PYGLIB_DEFINE_TYPE("gobject.GPropsDescr", PyGPropsDescr_Type, _empty);
+PYGLIB_DEFINE_TYPE("gobject.GPropsDescr", PyGPropsDescr_Type, PyObject);
 
 static PyObject *
 pyg_props_descr_descr_get(PyObject *self, PyObject *obj, PyObject *type)
@@ -872,6 +873,14 @@ pygobject_lookup_class(GType gtype)
     py_type = g_type_get_qdata(gtype, pygobject_class_key);
     if (py_type == NULL) {
 	py_type = g_type_get_qdata(gtype, pyginterface_type_key);
+
+    if (py_type == NULL) {
+        py_type = (PyTypeObject *)pygi_type_import_by_g_type(gtype);
+        if (py_type == NULL) {
+            PyErr_Clear();
+        }
+    }
+
 	if (py_type == NULL) {
 	    py_type = pygobject_new_with_interfaces(gtype);
 	    g_type_set_qdata(gtype, pyginterface_type_key, py_type);
